netapp_ontap.models.s3_bucket_svm_cors_rules API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.s3_bucket_svm_cors_rules`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class S3BucketSvmCorsRulesSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the S3BucketSvmCorsRules object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `allowed_headers: List[str] GET POST PATCH`

    An array of HTTP headers allowed in the cross-origin requests.

    Example: ["x-amz-request-id"]

  `allowed_methods: List[str] GET POST PATCH`

    An array of HTTP methods allowed in the cross-origin requests.

    Example: ["PUT","DELETE"]

  `allowed_origins: List[str] GET POST PATCH`

    List of origins from where a cross-origin request is allowed to originate from for the S3 bucket.

    Example: ["http://www.example.com"]

  `expose_headers: List[str] GET POST PATCH`

    List of extra headers sent in the response that customers can access from their applications.

    Example: ["x-amz-date"]

  `id: str GET POST PATCH`

    Bucket CORS rule identifier. The length of the name can range from 0 to 256 characters.

  `links: SelfLink GET`

    The links field of the s3_bucket_svm_cors_rules.

  `max_age_seconds: Size GET POST PATCH`

    The time in seconds for your browser to cache the preflight response for the specified resource.

    Example: 1024